/* 

07-Feb-00  I-03-26  JCN       $$1  Upgraded.
15-May-01  J-01-33  Shirish   $$2  Changed Success AWT Dialog  
			      to swing JOptionPane
06-Jul-01  J-03-02+ KB        $$3  Added package designation
09-Jul-01  J-03-02+ JCN       $$4  Undid #3
09-Jul-01  J-03-02+ JCN       $$5  Undid #3 correctly
29-Oct-01  J-03-11  asenthil  $$6  Included Sequence Checks for the Builtin DataTypes.
30-Jan-03  J-03-41  JCN       $$7  Used default frame for message pane.
*/

import java.awt.*;
import javax.swing.*;

import com.ptc.cipjava.*;
import com.ptc.pfc.pfcSession.*;
import com.ptc.pfc.pfcModel.*;
import com.ptc.pfc.pfcSolid.*;
import com.ptc.pfc.pfcModelItem.*;
import com.ptc.pfc.pfcFeature.*;
import com.ptc.pfc.pfcExceptions.*;

/**
 * The pfcInstallTest makes sure that J-Link has been properly
 * installed on your machine.
 * It test the pfc and cipjava package functionality
 * to make sure that those appear correctly in your CLASSPATH
 **/


public class pfcInstallTest{

  private Session proeSession;
  private int numberOfFeatures;
  private int numberOfModels;
  private Feature proeFeature;
  private Model proeModel;
  private Models proeModels;
  private ModelItems proeModelItems;

  public pfcInstallTest(Session inSession){
    
    proeSession=inSession;
    String ModelName = "pfcinstalltest";
    boolean status;
    
    status = loadModel(ModelName);

    //sleep 2 sec
    try{
      Thread.sleep(2000);
    }
    catch(InterruptedException e){
      e.printStackTrace();
    }

    if (status) 
      {
	//Print the information about each feature in the model
	//Test the functionality of the cip package using stringsequences
	// Test exception throwing/handling
	// Test action listeners
	// Unlooad the model
	status = getInfo() && testCIP() && testException() && testActionListeners() && unloadModel() && testSequences();
   
      }

    if (status)
      {
	JOptionPane.showMessageDialog ( null, "Install Test Sucessful",
		"J-Link Install Test Result", JOptionPane.INFORMATION_MESSAGE ); 

      }
    else
      {
      JOptionPane.showMessageDialog ( null, "Install Test Has Failed",
                "J-Link Install Test Result", JOptionPane.ERROR_MESSAGE ); 
      }
  }
  
  /**
   * This function loads the model and displays it in the Pro/E Session
   **/

  public boolean loadModel(String sampleName){
    ModelType mdl_type = ModelType.MDL_PART;

    try{
      ModelDescriptor proeModelDescriptor=
	    pfcModel.ModelDescriptor_Create (mdl_type ,sampleName, "");
        printMsg("Created model descriptor: "+(sampleName)+ " type: "+mdl_type.getValue());
 
        proeModel = proeSession.RetrieveModel(proeModelDescriptor);
	proeModel.Display();
        printMsg("Model was retrieved)");
    }
    catch(jxthrowable x){
      printMsg("pfcException: " + x);
      x.printStackTrace ();
      return false;
    }
    return true;
  }

  /**
   * This function prints all the information about every model in 
   * the current session.
   **/

  public boolean getInfo() 
    {
    try
      {
	
	proeModels=proeSession.ListModels();
	numberOfModels=proeModels.getarraysize();
	
	for (int i = 0; i < numberOfModels; ++i)
	  {
	    proeModel = proeModels.get(i);
	    proeModelItems = proeModel.ListItems (ModelItemType.ITEM_FEATURE);
	    
	    
	    numberOfFeatures=proeModelItems.getarraysize();
	    for (int j = 0; j < numberOfFeatures; ++j)
	      {
		proeFeature = (Feature)proeModelItems.get(j);
		printMsg("=========================================");
		printMsg("Feature regen # "+proeFeature.GetNumber());
		printMsg("Name: "+proeFeature.GetName ());
		printMsg("ID:   "+proeFeature.GetId());
		printMsg("Type: "+ModelItemType.getValue(proeFeature.GetType ()));
		printMsg("=========================================");
	      }    
	  }
      }
    catch(jxthrowable x)
      {
	x.printStackTrace ();
	return false;
      }
    return true;
    }
  
  /**
   * testCIP() tests the functionality of strinseq structure
   * in cipjava package.
   */
    
  public boolean testCIP(){
    try{
      proeSession.GetCurrentWindow().Repaint();
      stringseq seq = stringseq.create();
      seq.insert(0, "J-Link");
      seq.insert(1, "Install");
      seq.insert(2, "Test");
      
      for (int i = 0; i < seq.getarraysize(); i++)
        printMsg("Sequence member: "+ seq.get(i));
    
    }
    catch(jxthrowable x){
      printMsg("pfcException: " + x);
      x.printStackTrace ();
      return false;
    }
    return true;
  }
    
  /**
   * This method does the cleanup, by erasing the model
   * and closing the current window. Upon completion
   * i will pop up a message window with the success message.
   **/
  public boolean unloadModel(){
    try{
     
      proeModel.Erase();
     
    }
    catch(jxthrowable x){
      System.out.println("pfcException: " + x);
      x.printStackTrace ();
      return false;     
    }
    return true;
  }
    

    
  /**
   * Test that exceptions are thrown and caught properly  
   */
  public boolean testException ()
    {
      try
	{
	  proeSession.SetConfigOption ("Not a valid config option", "Not a valid value");
	}
      catch (XToolkitNotFound xtknf)
	{
	  try
	    {
	      printMsg ("(Expected) exception caught: "+xtknf);
	      printMsg ("    Toolkit function name: "+xtknf.GetToolkitFunctionName());
	      printMsg ("    Toolkit error code: "+xtknf.GetErrorCode ());
	    }
	  catch (Throwable x)
	    {
	      printMsg ("Unexpected exception caught: "+x);
	      x.printStackTrace ();
	      return false;
	    }
	}
      catch (Throwable x)
	    {
	      printMsg ("Unexpected exception caught: "+x);
	      x.printStackTrace ();
	      return false;
	    }
      return true;
    }

  /**
   *  Test that action listeners can be added and removed.
   */
  public boolean testActionListeners ()
    {
      Solid part = (Solid) proeModel;
      boolean status = true;
      try
	{ 
	  RegenAL al1 = new RegenAL();
	  
	  proeSession.AddActionListener (al1);
	  
	  part.Regenerate (null);
	  
	  Thread.sleep (5000);
	  
	  if (al1.getLastRegenedModelName ().equalsIgnoreCase ( part.GetInstanceName()))
	    printMsg ("ActionListener fired successfully");
	  else
	    {
	      printMsg ("ActionListener failed to fire");
	      status = false;
	    }
	      

	  proeSession.RemoveActionListener (al1);
	}
      catch (Throwable x)
	{
	  printMsg ("Exception caught: "+x);
	  x.printStackTrace ();
	  return false;
	}
      return status;
    }
/*=================================================================
    Check the Sequences for the DataTypes:int, real, bool, string
==================================================================*/
 
 public boolean testSequences()
    {
        boolean status = true;
	intseq iSeq, insertISeq;
	stringseq sSeq, insertSSeq;
	realseq rSeq, insertRSeq;
	booleanseq bSeq, insertBSeq;

	int int1 = 1;
	int int2 = 2;
	int int3 = 3;
 
	double real1 = 10.50;
	double real2 = 20.50;
	double real3 = 30.75;

	boolean  bool1 =  true;
	boolean  bool2 =  false;
	boolean  bool3 =  false;

	String str1 =  "string_element_1";
	String str2 =  "string_element_2";
	String str3 =  "string_element_3";


	try 
	{
	    iSeq = intseq.create();
	    printMsg("Initial array size: "+iSeq.getarraysize());
	    iSeq.set(0, int1);
	    iSeq.insert(0, int2);
	    printMsg("Int seq @ 0: "+iSeq.get(0)+ " int seq @ 1: "+iSeq.get(1));
	    insertISeq = intseq.create();
	    insertISeq.set(0, int3);
	    insertISeq.insert(0, int1);
	    printMsg("New int seq @ 0: "+insertISeq.get(0)+ " int seq @ 1: "+insertISeq.get(1));       
	    iSeq.insertseq(0, insertISeq);
	    iSeq.removerange(0,1);
	    printMsg("Final array size: "+iSeq.getarraysize());
	    printMsg("Int seq @ 0: "+iSeq.get(0)+ " int seq @ 1: " +iSeq.get(1)+ " int seq @ 2: "+iSeq.get(2) );
	}

        catch (Throwable x)
	{
	    printMsg ("Exception caught: "+x);
	    x.printStackTrace ();
	    return false;
	}

	try 
	{
	    rSeq = realseq.create();
	    printMsg("Initial array size: "+rSeq.getarraysize());
	    rSeq.set(0, real1);
	    rSeq.insert(0, real2);
	    printMsg("Real seq @ 0: "+rSeq.get(0)+ " Real seq @ 1: "+ rSeq.get(1));
	    insertRSeq = realseq.create();
	    insertRSeq.set(0, real3);
	    insertRSeq.insert(0, real1);
	    printMsg("New real seq @ 0: "+insertRSeq.get(0)+ " real seq @ 1: "+insertRSeq.get(1));       
	    rSeq.insertseq(0, insertRSeq);
	    rSeq.removerange(0,1);
	    printMsg("Final array size: "+rSeq.getarraysize());
	    printMsg("Real seq @ 0: "+rSeq.get(0)+ " Real seq @ 1: " +rSeq.get(1)+ " Real seq @ 2: "+rSeq.get(2));

	}

        catch (Throwable x)
	{
	    printMsg ("Exception caught: "+x);
	    x.printStackTrace ();
	    return false;
	}
	
	try 
	{
	    bSeq = booleanseq.create();
	    printMsg("Initial array size: "+bSeq.getarraysize());
	    bSeq.set(0, bool1);
	    bSeq.insert(0, bool2);
	    printMsg("Bool seq @ 0: "+bSeq.get(0)+ " Bool seq @ 1: "+bSeq.get(1));
	    insertBSeq = booleanseq.create();
	    insertBSeq.set(0, bool3);
	    insertBSeq.insert(0, bool1);
	    printMsg("New bool seq @ 0: "+insertBSeq.get(0)+ " bool seq @ 1: "+insertBSeq.get(1));       
	    bSeq.insertseq(0, insertBSeq);
	    bSeq.removerange(0,1);
	    printMsg("Final array size: "+bSeq.getarraysize());
	    printMsg("Bool seq @ 0: "+bSeq.get(0)+ " Bool seq @ 1: "+bSeq.get(1)+ " Bool seq @ 2: "+bSeq.get(2) );
	}

        catch (Throwable x)
	{
	    printMsg ("Exception caught: "+x);
	    x.printStackTrace ();
	    return false;
	}

	try 
	{
	    sSeq = stringseq.create();
	    printMsg("Initial array size: "+sSeq.getarraysize());
	    sSeq.set(0, str1);
	    sSeq.insert(0, str2);
	    printMsg("String seq @ 0: "+sSeq.get(0)+ " str seq @ 1: "+sSeq.get(1));
	    insertSSeq = stringseq.create();
	    insertSSeq.set(0, str3);
	    insertSSeq.insert(0, str1);
	    printMsg("New str seq @ 0: "+insertSSeq.get(0)+ " str seq @ 1: "+insertSSeq.get(1));       
	    sSeq.insertseq(0, insertSSeq);
	    sSeq.removerange(0,1);
	    printMsg("Final array size: "+sSeq.getarraysize());
	    printMsg("String seq @ 0: "+sSeq.get(0)+ " str seq @ 1: "+sSeq.get(1)+ " str seq @ 2 : "+sSeq.get(2));
	}

        catch (Throwable x)
	{
	    printMsg ("Exception caught: "+x);
	    x.printStackTrace ();
	    return false;
	}
      return status;
    }
  
  /**
   * printMsg just prints the message to the standard output
   * with a starting header.
   */
  public static void printMsg (String str) {
    System.out.println("J-Link install test: " + str); 
  }
}

class RegenAL extends com.ptc.pfc.pfcSolid.DefaultSolidActionListener {

  Model lastModel = null;

  public RegenAL ()
    {
    }

  public void OnAfterRegen (Solid sld, Feature feat, boolean wasSucc)
    {
      pfcInstallTest.printMsg ("Action listener firing!");
      lastModel = sld;
    }
      

  public String getLastRegenedModelName () throws com.ptc.cipjava.jxthrowable
    {
      if (lastModel == null)
	return "None";
      return lastModel.GetInstanceName ();
    }

}

    
   

  
	   


    
    


  
    

    
	    
	    
    
    
    


